//------------------------------------------------------------------------------
// Lamp : Open source game middleware
// Copyright (C) 2004  Junpei Ohtani ( Email : junpee@users.sourceforge.jp )
//
// This library is free software; you can redistribute it and/or
// modify it under the terms of the GNU Lesser General Public
// License as published by the Free Software Foundation; either
// version 2.1 of the License, or (at your option) any later version.
//
// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
//------------------------------------------------------------------------------

/** @file
 * 変換シーンノードインスタンスヘッダ
 * @author Junpee
 */

#ifndef TRANSLATION_SCENE_NODE_INSTANCE_H_
#define TRANSLATION_SCENE_NODE_INSTANCE_H_

#include "Translator/Instance/TranslationInstance.h"

namespace LampForMaya{

//------------------------------------------------------------------------------
/**
 * 変換シーンノードインスタンス
 */
class TranslationSceneNodeInstance : public TranslationInstance{
friend class TranslationInstanceManager;
public:
	/**
	 * デストラクタ
	 */
	virtual ~TranslationSceneNodeInstance();

	//--------------------------------------------------------------------------
	/**
	 * 分析
	 * @return 成功すればtrue
	 */
	virtual bool analyze();

	//--------------------------------------------------------------------------
	/**
	 * Lampへの変換
	 * @param scene シーン
	 * @return 成功すればtrue
	 */
	virtual bool convertToLamp(Scene* scene);

	/**
	 * アニメーションの変換
	 * @param animationManager アニメーションマネージャ
	 * @param animationSet アニメーションセット
	 * @return 成功すればtrue
	 */
	virtual bool convertAnimation(
		AnimationManager* animationManager, AnimationSet* animationSet){
		return convertSceneNodeAnimation(
			animationManager, animationSet, source_, destination_);
	}

	//--------------------------------------------------------------------------
	// RTTI
	//--------------------------------------------------------------------------
	/**
	 * 変換シーンノードインスタンスかどうか
	 * @return 変換シーンノードインスタンスならtrue
	 */
	virtual bool isTranslationSceneNodeInstance() const{ return true; }

protected:
	//--------------------------------------------------------------------------
	/**
	 * コンストラクタ
	 * @param initializePath 初期化するDagパス
	 * @param initializeName 初期化する名前
	 */
	TranslationSceneNodeInstance(
		const MDagPath& initializePath, const String& initializeName);

	/**
	 * ゼロチェック
	 * @param point チェックするポイント
	 * @return ポイントが0ならtrueを返す
	 */
	virtual bool zeroCheck(const MPoint& point){
		if(	(Math::abs((float)point.x) > Math::epsilon) ||
			(Math::abs((float)point.y) > Math::epsilon) ||
			(Math::abs((float)point.z) > Math::epsilon)){
			return false;
		}
		return true;
	}

	/// コピー元
	SceneNode* source_;
	/// コピー先
	SceneNode* destination_;
	/// ピボット
	Vector3 pivot_;
	/// スケール
	Vector3 scale_;
	/// 回転
	Vector3 rotation_;
	/// 移動
	Vector3 translation_;

};

//------------------------------------------------------------------------------
} // End of namespace LampForMaya
#endif // End of TRANSLATION_SCENE_NODE_INSTANCE_H_
//------------------------------------------------------------------------------
